==> pyside2-5.15.9-2-x86_64.pkg.tar.zst: usr/lib/cmake/PySide2-5.15.8/PySide2Config.cpython-311-x86_64-linux-gnu.cmake <==
#  PYSIDE_PYTHONPATH    - Path to where the PySide2 Python module files could be found
#  PYSIDE_TYPESYSTEMS   - Type system files that should be used by other bindings extending PySide2
#  PYSIDE_GLUE          - Path to module glue files.


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was PySide2Config-spec.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/PySide2-5.15.8" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Import targets only when using an installed PySide2 config file (so not during a regular
# PySide2 build, or during a super project build).
if (NOT TARGET PySide2::pyside2)
    include("${CMAKE_CURRENT_LIST_DIR}/PySide2Targets.cmake")
endif()

# Set relocatable variables.
set_and_check(PYSIDE_PYTHONPATH "${PACKAGE_PREFIX_DIR}/lib/python3.11/site-packages/PySide2")
set_and_check(PYSIDE_TYPESYSTEMS "${PACKAGE_PREFIX_DIR}/share/PySide2/typesystems")
set_and_check(PYSIDE_GLUE "${PACKAGE_PREFIX_DIR}/share/PySide2/glue")

==> pyside2-5.15.13-1-x86_64.pkg.tar.zst: usr/lib/cmake/PySide2-5.15.13/PySide2Config.cpython-311-x86_64-linux-gnu.cmake <==
#  PYSIDE_PYTHONPATH    - Path to where the PySide2 Python module files could be found
#  PYSIDE_TYPESYSTEMS   - Type system files that should be used by other bindings extending PySide2
#  PYSIDE_GLUE          - Path to module glue files.


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was PySide2Config-spec.cmake.in                            ########

get_filename_component(PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_2 "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/PySide2-5.15.13" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_2 "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Import targets only when using an installed PySide2 config file (so not during a regular
# PySide2 build, or during a super project build).
if (NOT TARGET PySide2::pyside2)
    include("${CMAKE_CURRENT_LIST_DIR}/PySide2Targets.cmake")
endif()

# Set relocatable variables.
set_and_check(PYSIDE_PYTHONPATH "${PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_2}/lib/python3.11/site-packages/PySide2")
set_and_check(PYSIDE_TYPESYSTEMS "${PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_2}/share/PySide2/typesystems")
set_and_check(PYSIDE_GLUE "${PACKAGE_${CMAKE_FIND_PACKAGE_NAME}_COUNTER_2}/share/PySide2/glue")
